@@ -27,7 +27,6 @@ DecoratedClient::~DecoratedClient() = default;
 
 DELEGATE(bool, isActive)
 DELEGATE(QString, caption)
-DELEGATE(int, desktop)
 DELEGATE(bool, isOnAllDesktops)
 DELEGATE(bool, isShaded)
 DELEGATE(QIcon, icon)
@@ -71,9 +70,9 @@ bool DecoratedClient::isApplicationMenuActive() const
     return false;
 }
 
-QPointer<Decoration> DecoratedClient::decoration() const
+Decoration *DecoratedClient::decoration() const
 {
-    return QPointer<Decoration>(d->decoration());
+    return d->decoration();
 }
 
 QColor DecoratedClient::color(QPalette::ColorGroup group, QPalette::ColorRole role) const
@@ -94,3 +93,5 @@ void DecoratedClient::showApplicationMenu(int actionId)
 }
 
 } // namespace
+
+#include "moc_decoratedclient.cpp"
